==> pass_mtx-0.0.21.tar.gz: lib/pass_mtx_method_channel.dart <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'pass_mtx_platform_interface.dart';

/// An implementation of [PassMtxPlatform] that uses method channels.
class MethodChannelPassMtx extends PassMtxPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('pass_mtx');

  @override
  Future<String?> getPlatformVersion() async {
    final result =
        await methodChannel.invokeMethod<String>('getPlatformVersion');
    return "$result";
  }

  @override
  Future<String?> getPassPing() async {
    final pingResult = await methodChannel.invokeMethod<String>('getPassPing');
    return "$pingResult";
  }

  @override
  Future<String?> getPassVersion() async {
    final result = await methodChannel.invokeMethod<String>('getPassVersion');
    return "$result";
  }

  @override
  Future<String?> init(String appId, String clientId, String privatePem,
      String publicPem) async {
    final result = await methodChannel.invokeMethod<String>('passStageInit', {
      "app_id": appId,
      "client_id": clientId,
      "private_pem": privatePem,
      "public_pem": publicPem,
    });
    return "$result";
  }

  @override
  Future<String?> initProd(String appId, String clientId, String privatePem,
      String publicPem) async {
    final result = await methodChannel.invokeMethod<String>('passInit', {
      "app_id": appId,
      "client_id": clientId,
      "private_pem": privatePem,
      "public_pem": publicPem,
    });
    return "$result";
  }

  @override
  Future<String?> getCard(String userId) async {
    final result = await methodChannel
        .invokeMethod<String>('getCard', {"user_id": userId});
    return "$result";
  }

  @override
  Future<String?> saveCard(String userId, String szPan, String cvv,
      String expDate, String cardHolderName) async {
    final result = await methodChannel.invokeMethod<String>('saveCard', {
      "user_id": userId,
      "card_pan": szPan,
      "cvv": cvv,
      "exp_date": expDate,
      "card_holder_name": cardHolderName
    });
    return "$result";
  }

  @override
  Future<String?> purchase(
      String userId,
      String orderId,
      String paymentToken,
      String expDate,
      String paymentAmount,
      String dbRefNo,
      String description) async {
    final result = await methodChannel.invokeMethod<String>('purchase', {
      "user_id": userId,
      "order_id": orderId,
      "payment_token": paymentToken,
      "payment_amount": paymentAmount,
      "expire_date": expDate,
      "db_ref_no": dbRefNo,
      "description": description
    });
    return "$result";
  }

  @override
  Future<String?> enquery(String orderId) async {
    final result = await methodChannel
        .invokeMethod<String>('enquery', {"order_id": orderId});
    return "$result";
  }

  @override
  Future<String?> deleteCard(String userId) async {
    final result = await methodChannel
        .invokeMethod<String>('deleteCard', {"user_id": userId});
    return "$result";
  }

  @override
  Future<String?> verifyCard(String userId, String verificationMethod,
      String verificationValue) async {
    final result = await methodChannel.invokeMethod<String>('verifyCard', {
      "user_id": userId,
      "verification_method": verificationMethod,
      "verification_value": verificationValue
    });
    return "$result";
  }

  @override
  Future<String?> passGetQr(String userId, String orderId, String payToken,
      String expDate, String ttl) async {
    final result = await methodChannel.invokeMethod<String>('getQr', {
      "user_id": userId,
      "order_id": orderId,
      "payment_token": payToken,
      "exp_date": expDate,
      "ttl": ttl
    });
    return "$result";
  }

  @override
  Future<String?> orderEnquery(String userId, String orderId) async {
    final result = await methodChannel.invokeMethod<String>('orderEnquery', {
      "user_id": userId,
      "order_id": orderId,
    });
    return "$result";
  }

  @override
  Future<String?> orderConfirm(
      String userId,
      String orderId,
      String confirmMethod,
      String confirmResult,
      String payToken,
      String expDate) async {
    final result = await methodChannel.invokeMethod<String>('orderConfirm', {
      "user_id": userId,
      "order_id": orderId,
      "confirm_method": confirmMethod,
      "confirm_result": confirmResult,
      "payment_token": payToken,
      "exp_date": expDate,
    });
    return "$result";
  }

  @override
  Future<String?> orderCancel(String userId, String orderId) async {
    final result = await methodChannel.invokeMethod<String>('orderCancel', {
      "user_id": userId,
      "order_id": orderId,
    });
    return "$result";
  }
}

==> pass_mtx-0.0.23.tar.gz: lib/pass_mtx_method_channel.dart <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'pass_mtx_platform_interface.dart';

/// An implementation of [PassMtxPlatform] that uses method channels.
class MethodChannelPassMtx extends PassMtxPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('pass_mtx');

  @override
  Future<String?> getPlatformVersion() async {
    final result =
        await methodChannel.invokeMethod<String>('getPlatformVersion');
    return "$result";
  }

  @override
  Future<String?> getPassPing() async {
    final pingResult = await methodChannel.invokeMethod<String>('getPassPing');
    return "$pingResult";
  }

  @override
  Future<String?> getPassVersion() async {
    final result = await methodChannel.invokeMethod<String>('getPassVersion');
    return "$result";
  }

  @override
  Future<String?> init(String appId, String clientId, String privatePem,
      String publicPem) async {
    final result = await methodChannel.invokeMethod<String>('passStageInit', {
      "app_id": appId,
      "client_id": clientId,
      "private_pem": privatePem,
      "public_pem": publicPem,
    });
    return "$result";
  }

  @override
  Future<String?> initProd(String appId, String clientId, String privatePem,
      String publicPem) async {
    final result = await methodChannel.invokeMethod<String>('passInit', {
      "app_id": appId,
      "client_id": clientId,
      "private_pem": privatePem,
      "public_pem": publicPem,
    });
    return "$result";
  }

  @override
  Future<String?> getCard(String userId) async {
    final result = await methodChannel
        .invokeMethod<String>('getCard', {"user_id": userId});
    return "$result";
  }

  @override
  Future<String?> saveCard(String userId, String szPan, String cvv,
      String expDate, String cardHolderName) async {
    final result = await methodChannel.invokeMethod<String>('saveCard', {
      "user_id": userId,
      "card_pan": szPan,
      "cvv": cvv,
      "exp_date": expDate,
      "card_holder_name": cardHolderName
    });
    return "$result";
  }

  @override
  Future<String?> purchase(
      String userId,
      String orderId,
      String paymentToken,
      String expDate,
      String paymentAmount,
      String dbRefNo,
      String description) async {
    final result = await methodChannel.invokeMethod<String>('purchase', {
      "user_id": userId,
      "order_id": orderId,
      "payment_token": paymentToken,
      "payment_amount": paymentAmount,
      "expire_date": expDate,
      "db_ref_no": dbRefNo,
      "description": description
    });
    return "$result";
  }

  @override
  Future<String?> enquery(String orderId) async {
    final result = await methodChannel
        .invokeMethod<String>('enquery', {"order_id": orderId});
    return "$result";
  }

  @override
  Future<String?> deleteCard(String userId, String card_ref) async {
    final result = await methodChannel.invokeMethod<String>(
        'deleteCard', {"user_id": userId, "card_ref": card_ref});
    return "$result";
  }

  @override
  Future<String?> verifyCard(String userId, String verificationMethod,
      String verificationValue) async {
    final result = await methodChannel.invokeMethod<String>('verifyCard', {
      "user_id": userId,
      "verification_method": verificationMethod,
      "verification_value": verificationValue
    });
    return "$result";
  }

  @override
  Future<String?> passGetQr(String userId, String orderId, String payToken,
      String expDate, String ttl) async {
    final result = await methodChannel.invokeMethod<String>('getQr', {
      "user_id": userId,
      "order_id": orderId,
      "payment_token": payToken,
      "exp_date": expDate,
      "ttl": ttl
    });
    return "$result";
  }

  @override
  Future<String?> orderEnquery(String userId, String orderId) async {
    final result = await methodChannel.invokeMethod<String>('orderEnquery', {
      "user_id": userId,
      "order_id": orderId,
    });
    return "$result";
  }

  @override
  Future<String?> orderConfirm(
      String userId,
      String orderId,
      String confirmMethod,
      String confirmResult,
      String payToken,
      String expDate) async {
    final result = await methodChannel.invokeMethod<String>('orderConfirm', {
      "user_id": userId,
      "order_id": orderId,
      "confirm_method": confirmMethod,
      "confirm_result": confirmResult,
      "payment_token": payToken,
      "exp_date": expDate,
    });
    return "$result";
  }

  @override
  Future<String?> orderCancel(String userId, String orderId) async {
    final result = await methodChannel.invokeMethod<String>('orderCancel', {
      "user_id": userId,
      "order_id": orderId,
    });
    return "$result";
  }
}
